@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 
 using namespace MailCommon;
 
-FilterConvertToSieve::FilterConvertToSieve(const QList<MailFilter *> &filters)
+FilterConvertToSieve::FilterConvertToSieve(const QVector<MailFilter *> &filters)
     : mListFilters(filters)
 {
 }
