@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -40,7 +40,7 @@ void FilterImportThunderbirdtest::testImportFiltersAllCondition()
                                           "action=\"Mark read\"\n"
                                           "condition=\"ALL\"\n");
     MailCommon::FilterImporterThunderbird importer(filter, false);
-    QList<MailCommon::MailFilter *> lst = importer.importFilter();
+    QVector<MailCommon::MailFilter *> lst = importer.importFilter();
     QCOMPARE(lst.count(), 1);
     MailCommon::MailFilter *f = lst.at(0);
     QVERIFY(f->isEnabled());
@@ -54,7 +54,7 @@ void FilterImportThunderbirdtest::testImportFiltersEmpty()
 {
     QString filter;
     MailCommon::FilterImporterThunderbird importer(filter, false);
-    QList<MailCommon::MailFilter *> lst = importer.importFilter();
+    QVector<MailCommon::MailFilter *> lst = importer.importFilter();
     QCOMPARE(lst.count(), 0);
 }
 
@@ -69,7 +69,7 @@ void FilterImportThunderbirdtest::testImportFiltersStopExecution()
                                           "action=\"Mark read\"\n"
                                           "condition=\"ALL\"\n");
     MailCommon::FilterImporterThunderbird importer(filter, false);
-    QList<MailCommon::MailFilter *> lst = importer.importFilter();
+    QVector<MailCommon::MailFilter *> lst = importer.importFilter();
     MailCommon::MailFilter *f = lst.at(0);
     QVERIFY(f->isEnabled());
     QCOMPARE(f->stopProcessingHere(), true);
@@ -87,7 +87,7 @@ void FilterImportThunderbirdtest::testImportFiltersDisabled()
                                           "action=\"Mark read\"\n"
                                           "condition=\"ALL\"\n");
     MailCommon::FilterImporterThunderbird importer(filter, false);
-    QList<MailCommon::MailFilter *> lst = importer.importFilter();
+    QVector<MailCommon::MailFilter *> lst = importer.importFilter();
     MailCommon::MailFilter *f = lst.at(0);
     QCOMPARE(f->isEnabled(), false);
     QCOMPARE(f->stopProcessingHere(), true);
@@ -112,7 +112,7 @@ void FilterImportThunderbirdtest::testImportTwoFilters()
                                           "action=\"Mark read\"\n"
                                           "condition=\"AND (subject,contains,kmail) AND (subject,contains,konqueror) AND (subject,contains,kf5) AND (subject,contains,qtcreator)\"\n");
     MailCommon::FilterImporterThunderbird importer(filter, false);
-    QList<MailCommon::MailFilter *> lst = importer.importFilter();
+    QVector<MailCommon::MailFilter *> lst = importer.importFilter();
     QCOMPARE(lst.count(), 2);
     MailCommon::MailFilter *f = lst.at(0);
     QCOMPARE(f->pattern()->op(), MailCommon::SearchPattern::OpAnd);
@@ -135,7 +135,7 @@ void FilterImportThunderbirdtest::testImportAndFilters()
                                           "actionValue=\"mailbox://kde@pop.kde.org/Inbox\"\n"
                                           "condition=\"AND (subject,contains,konqi)\"\n");
     MailCommon::FilterImporterThunderbird importer(filter, false);
-    QList<MailCommon::MailFilter *> lst = importer.importFilter();
+    QVector<MailCommon::MailFilter *> lst = importer.importFilter();
     MailCommon::MailFilter *f = lst.at(0);
     QCOMPARE(f->pattern()->op(), MailCommon::SearchPattern::OpAnd);
     qDeleteAll(lst);
@@ -152,7 +152,7 @@ void FilterImportThunderbirdtest::testImportOrFilters()
                                           "actionValue=\"mailbox://kde@pop.kde.org/Inbox\"\n"
                                           "condition=\"OR (subject,contains,konqi)\"\n");
     MailCommon::FilterImporterThunderbird importer(filter, false);
-    QList<MailCommon::MailFilter *> lst = importer.importFilter();
+    QVector<MailCommon::MailFilter *> lst = importer.importFilter();
     MailCommon::MailFilter *f = lst.at(0);
     QCOMPARE(f->pattern()->op(), MailCommon::SearchPattern::OpOr);
     qDeleteAll(lst);
@@ -183,7 +183,7 @@ void FilterImportThunderbirdtest::testImportTypeFilters()
                                           "action=\"Mark read\"\n"
                                           "condition=\"AND (subject,contains,kmail) AND (subject,contains,konqueror) AND (subject,contains,kf5) AND (subject,contains,qtcreator)\"\n");
     MailCommon::FilterImporterThunderbird importer(filter, false);
-    QList<MailCommon::MailFilter *> lst = importer.importFilter();
+    QVector<MailCommon::MailFilter *> lst = importer.importFilter();
 
     MailCommon::MailFilter *f = lst.at(0);
     //17
