@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,11 +20,11 @@
 #define MAILCOMMON_FILTERIMPORTER_FILTERIMPORTERABSTRACT_P_H
 
 #include "mailcommon_export.h"
-#include <QDomDocument>
 #include <QVector>
 #include <QStringList>
 
 class QFile;
+class QDomDocument;
 
 namespace MailCommon {
 class MailFilter;
