@@ -25,8 +25,7 @@ namespace MailCommon {
 class SearchRuleEncryption : public SearchRule
 {
 public:
-    explicit SearchRuleEncryption(const QByteArray &field =
-        {
+    explicit SearchRuleEncryption(const QByteArray &field = {
         }, Function func = FuncEquals, const QString &contents = {});
     ~SearchRuleEncryption() override;
 
